@@ -584,7 +584,7 @@ def parse_options():
                       help = "Use a specific image file instead of a fresh one")
     parser.add_option('--emulator-res',
                       action = 'store', dest = 'emulator_res',
-                      default = '480x800', type= 'str',
+                      default = None, type= 'str',
                       help = 'Set a custom resolution for the emulator. '
                       'Example: "480x800"')
     parser.add_option("--no-window",
@@ -657,11 +657,12 @@ def parse_options():
 
     # check for valid resolution string, strip whitespaces
     try:
-        dims = options.emulator_res.split('x')
-        assert len(dims) == 2
-        width = str(int(dims[0]))
-        height = str(int(dims[1]))
-        options.emulator_res = 'x'.join([width, height])
+        if options.emulator_res:
+            dims = options.emulator_res.split('x')
+            assert len(dims) == 2
+            width = str(int(dims[0]))
+            height = str(int(dims[1]))
+            options.emulator_res = 'x'.join([width, height])
     except:
         raise ValueError('Invalid emulator resolution format. '
                          'Should be like "480x800".')
